pub async fn delete(conn: &mut PgConnection, id: Uuid) -> ModelResult<()>Expand description
Soft-deletes the configuration’s requirements too, so run this in a transaction.
pub async fn delete(conn: &mut PgConnection, id: Uuid) -> ModelResult<()>Soft-deletes the configuration’s requirements too, so run this in a transaction.